@@ -11,6 +11,7 @@ from copy import deepcopy
 
 from tiddlyweb.specialbag import get_bag_retriever, SpecialBagError
 from tiddlyweb.model.policy import Policy
+from tiddlyweb.util import superclass_name
 
 
 class StoreError(IOError):
@@ -120,7 +121,8 @@ class Store(object):
             try:
                 imported_module = __import__(self.engine, {}, {}, ['Store'])
             except ImportError, err:
-                raise ImportError("couldn't load store for %s: %s, %s" % (self.engine, err, err1))
+                raise ImportError("couldn't load store for %s: %s, %s"
+                        % (self.engine, err, err1))
         self.storage = imported_module.Store(self.config, self.environ)
 
     def delete(self, thing):
@@ -136,7 +138,7 @@ class Store(object):
         """
         Get a thing: recipe, bag or tiddler
         """
-        lower_class = thing.__class__.__name__.lower()
+        lower_class = superclass_name(thing)
         if lower_class == 'tiddler':
             uri = thing.bag
             retriever = get_bag_retriever(self.environ, thing.bag)
@@ -144,7 +146,8 @@ class Store(object):
                 try:
                     thing = retriever[1](thing)
                 except SpecialBagError, exc:
-                    raise NoTiddlerError('unable to get remote tiddler: %s:%s:%s'
+                    raise NoTiddlerError(
+                            'unable to get remote tiddler: %s:%s:%s'
                             % (thing.bag, thing.title, exc))
                 thing.store = self
                 self._do_hook('get', thing)
@@ -180,11 +183,12 @@ class Store(object):
         Determine which function on the StorageInterface
         we should use to store or retrieve storable.
         """
-        lower_class = storable.__class__.__name__.lower()
+        lower_class = superclass_name(storable)
         try:
             func = getattr(self.storage, '%s_%s' % (lower_class, activity))
         except AttributeError, exc:
-            raise AttributeError('unable to figure function for %s: %s' % (lower_class, exc))
+            raise AttributeError('unable to figure function for %s: %s'
+                    % (lower_class, exc))
         return func
 
     def list_bags(self):
@@ -241,7 +245,7 @@ class Store(object):
         """
         Call the hook in HOOKS identified by method on thing.
         """
-        hooked_class = thing.__class__.__name__.lower()
+        hooked_class = superclass_name(thing)
         hooks = _get_hooks(method, hooked_class)
         for hook in hooks:
             hook(self, thing)
